"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const types_1 = require("@typescript-eslint/types");
const types_2 = require("../shared/types");
const util_1 = require("../util");
/** This function supports @babel/parser */
function isDynamicImport(node) {
    return (Boolean(node) &&
        node.callee &&
        // from @babel/parser
        node.callee.type === types_2.CEBABEL_PARSER_AST_NODE_TYPES.Import);
}
function isStaticValue(argument) {
    return (argument.type === types_1.AST_NODE_TYPES.Literal ||
        (argument.type === types_1.AST_NODE_TYPES.TemplateLiteral &&
            argument.expressions.length === 0));
}
exports.default = (0, util_1.createRule)({
    defaultOptions: [],
    name: 'no-esm-dynamic-import',
    meta: {
        type: 'suggestion',
        docs: {
            description: 'Using this rule to disable the use of dynamic require for CommonJS or ESM import.',
            recommended: false,
        },
        messages: {
            legacyParsersImportShouldBeLiteral: 'Calls to import() should use string literals',
            importShouldBeLiteral: 'Calls to import() should use string literals',
        },
        schema: [{}],
    },
    create(context) {
        return {
            CallExpression(node) {
                if (Boolean(node.arguments[0]) === false ||
                    isStaticValue(node.arguments[0])) {
                    return;
                }
                if (isDynamicImport(node)) {
                    context.report({
                        node,
                        messageId: 'legacyParsersImportShouldBeLiteral',
                    });
                }
            },
            ImportExpression(node) {
                if (isStaticValue(node.source)) {
                    return;
                }
                context.report({
                    node,
                    messageId: 'importShouldBeLiteral',
                });
            },
        };
    },
});
//# sourceMappingURL=no-esm-dynamic-import.js.map